@@ -100,9 +100,9 @@ if ($page == 'domains' || $page == 'overview') {
 		]);
 
 		if ($result['domain'] != '') {
-			if (isset($_POST['send']) && $_POST['send'] == 'send' && $alias_check['count'] == 0) {
+			if (Request::post('send') == 'send' && $alias_check['count'] == 0) {
 				try {
-					Domains::getLocal($userinfo, $_POST)->delete();
+					Domains::getLocal($userinfo, Request::postAll())->delete();
 				} catch (Exception $e) {
 					Response::dynamicError($e->getMessage());
 				}
@@ -113,7 +113,7 @@ if ($page == 'domains' || $page == 'overview') {
 			} elseif ($alias_check['count'] > 0) {
 				Response::standardError('domains_cantdeletedomainwithaliases');
 			} else {
-				HTML::askYesNo('admin_domain_reallydelete', $filename, [
+				HTML::askYesNoWithCheckbox('admin_domain_reallydelete', 'admin_customer_alsoremovemail', $filename, [
 					'id' => $id,
 					'page' => $page,
 					'action' => $action
@@ -121,9 +121,9 @@ if ($page == 'domains' || $page == 'overview') {
 			}
 		}
 	} elseif ($action == 'add') {
-		if (isset($_POST['send']) && $_POST['send'] == 'send') {
+		if (Request::post('send') == 'send') {
 			try {
-				Domains::getLocal($userinfo, $_POST)->add();
+				Domains::getLocal($userinfo, Request::postAll())->add();
 			} catch (Exception $e) {
 				Response::dynamicError($e->getMessage());
 			}
@@ -355,13 +355,13 @@ if ($page == 'domains' || $page == 'overview') {
 				$usedips[] = $ipsresultrow['id_ipandports'];
 			}
 
-			if (isset($_POST['send']) && $_POST['send'] == 'send') {
+			if (Request::post('send') == 'send') {
 				try {
 					// remove ssl ip/ports if set is empty
-					if (!isset($_POST['ssl_ipandport']) || empty($_POST['ssl_ipandport'])) {
+					if (empty(Request::post('ssl_ipandport'))) {
 						$_POST['remove_ssl_ipandport'] = true;
 					}
-					Domains::getLocal($userinfo, $_POST)->update();
+					Domains::getLocal($userinfo, Request::postAll())->update();
 				} catch (Exception $e) {
 					Response::dynamicError($e->getMessage());
 				}
@@ -572,13 +572,13 @@ if ($page == 'domains' || $page == 'overview') {
 			}
 		}
 	} elseif ($action == 'jqGetCustomerPHPConfigs') {
-		$customerid = intval($_POST['customerid']);
+		$customerid = intval(Request::post('customerid'));
 		$allowed_phpconfigs = Customer::getCustomerDetail($customerid, 'allowed_phpconfigs');
 		echo !empty($allowed_phpconfigs) ? $allowed_phpconfigs : json_encode([]);
 		exit();
 	} elseif ($action == 'jqSpeciallogfileNote') {
-		$domainid = intval($_POST['id']);
-		$newval = intval($_POST['newval']);
+		$domainid = intval(Request::post('id'));
+		$newval = intval(Request::post('newval'));
 		try {
 			$json_result = Domains::getLocal($userinfo, [
 				'id' => $domainid
@@ -594,9 +594,9 @@ if ($page == 'domains' || $page == 'overview') {
 		echo 0;
 		exit();
 	} elseif ($action == 'import') {
-		if (isset($_POST['send']) && $_POST['send'] == 'send') {
-			$separator = Validate::validate($_POST['separator'], 'separator');
-			$offset = (int)Validate::validate($_POST['offset'], 'offset', "/[0-9]/i");
+		if (Request::post('send') == 'send') {
+			$separator = Validate::validate(Request::post('separator'), 'separator');
+			$offset = (int)Validate::validate(Request::post('offset'), 'offset', "/[0-9]/i");
 
 			$file_name = $_FILES['file']['tmp_name'];
 
@@ -636,9 +636,9 @@ if ($page == 'domains' || $page == 'overview') {
 			]);
 		}
 	} elseif ($action == 'duplicate') {
-		if (isset($_POST['send']) && $_POST['send'] == 'send') {
+		if (Request::post('send') == 'send') {
 			try {
-				Domains::getLocal($userinfo, $_POST)->duplicate();
+				Domains::getLocal($userinfo, Request::postAll())->duplicate();
 			} catch (Exception $e) {
 				Response::dynamicError($e->getMessage());
 			}
