@@ -53,6 +53,8 @@ class Emails extends ApiCommand implements ResourceEntity
 	 *            domain-name for the email-address
 	 * @param float $spam_tag_level
 	 *            optional, score which is required to tag emails as spam, default: 7.0
+	 * @param bool $rewrite_subject
+	 *            optional, whether to add ***SPAM*** to the email's subject if applicable, default true
 	 * @param float $spam_kill_level
 	 *            optional, score which is required to discard emails, default: 14.0
 	 * @param boolean $bypass_spam
@@ -85,17 +87,19 @@ class Emails extends ApiCommand implements ResourceEntity
 
 			// parameters
 			$spam_tag_level = $this->getParam('spam_tag_level', true, '7.0');
-			$spam_kill_level = $this->getParam('spam_kill_level', true, '14.0');
+			$rewrite_subject = $this->getBoolParam('rewrite_subject', true, 1);
+			$spam_kill_level = $this->getUlParam('spam_kill_level', 'spam_kill_level_ul', true, '14.0');
 			$bypass_spam = $this->getBoolParam('bypass_spam', true, 0);
 			$policy_greylist = $this->getBoolParam('policy_greylist', true, 1);
 			$iscatchall = $this->getBoolParam('iscatchall', true, 0);
 			$description = $this->getParam('description', true, '');
 
 			// validation
+			$idna_convert = new IdnaWrapper();
 			if (substr($domain, 0, 4) != 'xn--') {
-				$idna_convert = new IdnaWrapper();
 				$domain = $idna_convert->encode(Validate::validate($domain, 'domain', '', '', [], true));
 			}
+			$email_part = $idna_convert->encode($email_part);
 
 			// check domain and whether it's an email-enabled domain
 			// use internal call because the customer might have 'domains' in customer_hide_options
@@ -103,10 +107,10 @@ class Emails extends ApiCommand implements ResourceEntity
 				'domainname' => $domain
 			], true);
 			if ((int)$domain_check['isemaildomain'] == 0) {
-				Response::standardError('maindomainnonexist', $domain, true);
+				Response::standardError('maindomainnonexist', $idna_convert->decode($domain), true);
 			}
 			if ((int)$domain_check['deactivated'] == 1) {
-				Response::standardError('maindomaindeactivated', $domain, true);
+				Response::standardError('maindomaindeactivated', $idna_convert->decode($domain), true);
 			}
 
 			if (Settings::Get('catchall.catchall_enabled') != '1') {
@@ -127,7 +131,7 @@ class Emails extends ApiCommand implements ResourceEntity
 
 			// validate it
 			if (!Validate::validateEmail($email_full)) {
-				Response::standardError('emailiswrong', $email_full, true);
+				Response::standardError('emailiswrong', $idna_convert->decode($email_full), true);
 			}
 
 			// get needed customer info to reduce the email-address-counter by one
@@ -148,14 +152,16 @@ class Emails extends ApiCommand implements ResourceEntity
 
 			if ($email_check) {
 				if (strtolower($email_check['email_full']) == strtolower($email_full)) {
-					Response::standardError('emailexistalready', $email_full, true);
+					Response::standardError('emailexistalready', $idna_convert->decode($email_full), true);
 				} elseif ($email_check['email'] == $email) {
 					Response::standardError('youhavealreadyacatchallforthisdomain', '', true);
 				}
 			}
 
-			$spam_tag_level = Validate::validate($spam_tag_level, 'spam_tag_level', '/^\d{1,}(\.\d{1,2})?$/', '', [7.0], true);
-			$spam_kill_level = Validate::validate($spam_kill_level, 'spam_kill_level', '/^\d{1,}(\.\d{1,2})?$/', '', [14.0], true);
+			$spam_tag_level = Validate::validate($spam_tag_level, 'spam_tag_level', '/^\d{1,}(\.\d{1})?$/', '', [7.0], true);
+			if ($spam_kill_level > -1) {
+				$spam_kill_level = Validate::validate($spam_kill_level, 'spam_kill_level', '/^\d{1,}(\.\d{1})?$/', '', [14.0], true);
+			}
 			$description = Validate::validate(trim($description), 'description', Validate::REGEX_DESC_TEXT, '', [], true);
 
 			$stmt = Database::prepare("
@@ -164,6 +170,7 @@ class Emails extends ApiCommand implements ResourceEntity
 				`email` = :email,
 				`email_full` = :email_full,
 				`spam_tag_level` = :spam_tag_level,
+				`rewrite_subject` = :rewrite_subject,
 				`spam_kill_level` = :spam_kill_level,
 				`bypass_spam` = :bypass_spam,
 				`policy_greylist` = :policy_greylist,
@@ -176,6 +183,7 @@ class Emails extends ApiCommand implements ResourceEntity
 				"email" => $email,
 				"email_full" => $email_full,
 				"spam_tag_level" => $spam_tag_level,
+				"rewrite_subject" => $rewrite_subject,
 				"spam_kill_level" => $spam_kill_level,
 				"bypass_spam" => $bypass_spam,
 				"policy_greylist" => $policy_greylist,
@@ -226,7 +234,7 @@ class Emails extends ApiCommand implements ResourceEntity
 			LEFT JOIN `" . TABLE_MAIL_USERS . "` u ON v.`popaccountid` = u.`id`
 			WHERE v.`customerid` IN (" . implode(", ", $customer_ids) . ")
 			AND " . (is_numeric($params['idea']) ? "v.`id`= :idea" : "(v.`email` = :idea OR v.`email_full` = :idea)"
-		));
+			));
 		$result = Database::pexecute_first($result_stmt, $params, true, true);
 		if ($result) {
 			$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_INFO, "[API] get email address '" . $result['email_full'] . "'");
@@ -249,6 +257,8 @@ class Emails extends ApiCommand implements ResourceEntity
 	 *            optional, required when called as admin (if $customerid is not specified)
 	 * @param float $spam_tag_level
 	 *            optional, score which is required to tag emails as spam, default: 7.0
+	 * @param bool $rewrite_subject
+	 *              optional, whether to add ***SPAM*** to the email's subject if applicable, default true
 	 * @param float $spam_kill_level
 	 *            optional, score which is required to discard emails, default: 14.0
 	 * @param boolean $bypass_spam
@@ -282,7 +292,8 @@ class Emails extends ApiCommand implements ResourceEntity
 
 		// parameters
 		$spam_tag_level = $this->getParam('spam_tag_level', true, $result['spam_tag_level']);
-		$spam_kill_level = $this->getParam('spam_kill_level', true, $result['spam_kill_level']);
+		$rewrite_subject = $this->getBoolParam('rewrite_subject', true, $result['rewrite_subject']);
+		$spam_kill_level = $this->getUlParam('spam_kill_level', 'spam_kill_level_ul', true, $result['spam_kill_level']);
 		$bypass_spam = $this->getBoolParam('bypass_spam', true, $result['bypass_spam']);
 		$policy_greylist = $this->getBoolParam('policy_greylist', true, $result['policy_greylist']);
 		$iscatchall = $this->getBoolParam('iscatchall', true, $result['iscatchall']);
@@ -326,13 +337,16 @@ class Emails extends ApiCommand implements ResourceEntity
 		}
 
 		$spam_tag_level = Validate::validate($spam_tag_level, 'spam_tag_level', '/^\d{1,}(\.\d{1,2})?$/', '', [7.0], true);
-		$spam_kill_level = Validate::validate($spam_kill_level, 'spam_kill_level', '/^\d{1,}(\.\d{1,2})?$/', '', [14.0], true);
+		if ($spam_kill_level > -1) {
+			$spam_kill_level = Validate::validate($spam_kill_level, 'spam_kill_level', '/^\d{1,}(\.\d{1,2})?$/', '', [14.0], true);
+		}
 		$description = Validate::validate(trim($description), 'description', Validate::REGEX_DESC_TEXT, '', [], true);
 
 		$stmt = Database::prepare("
 			UPDATE `" . TABLE_MAIL_VIRTUAL . "` SET
 			`email` = :email ,
 			`spam_tag_level` = :spam_tag_level,
+			`rewrite_subject` = :rewrite_subject,
 			`spam_kill_level` = :spam_kill_level,
 			`bypass_spam` = :bypass_spam,
 			`policy_greylist` = :policy_greylist,
@@ -343,6 +357,7 @@ class Emails extends ApiCommand implements ResourceEntity
 		$params = [
 			"email" => $email,
 			"spam_tag_level" => $spam_tag_level,
+			"rewrite_subject" => $rewrite_subject,
 			"spam_kill_level" => $spam_kill_level,
 			"bypass_spam" => $bypass_spam,
 			"policy_greylist" => $policy_greylist,
@@ -396,7 +411,10 @@ class Emails extends ApiCommand implements ResourceEntity
 			LEFT JOIN `" . TABLE_MAIL_USERS . "` u ON (m.`popaccountid` = u.`id`)
 			WHERE m.`customerid` IN (" . implode(", ", $customer_ids) . ")" . $this->getSearchWhere($query_fields, true) . $this->getOrderBy() . $this->getLimit());
 		Database::pexecute($result_stmt, $query_fields, true, true);
+		$idna_convert = new IdnaWrapper();
 		while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
+			$row['email'] = $idna_convert->decode($row['email']);
+			$row['email_full'] = $idna_convert->decode($row['email_full']);
 			$result[] = $row;
 		}
 		$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_INFO, "[API] list email-addresses");
