@@ -129,7 +129,7 @@ return [
 						'selected' => $result['subcanemaildomain']
 					],
 					'dkim' => [
-						'visible' => Settings::Get('dkim.use_dkim') == '1',
+						'visible' => Settings::Get('antispam.activated') == '1',
 						'label' => 'DomainKeys',
 						'type' => 'checkbox',
 						'value' => '1',
@@ -446,7 +446,25 @@ return [
 						'desc' => lng('admin.bindzonewarning'),
 						'type' => 'text',
 						'value' => $result['zonefile']
-					]
+					],
+					'spf_entry' => [
+						'visible' => (Settings::Get('system.bind_enable') == '0' && Settings::Get('spf.use_spf') == '1' && $result['isemaildomain'] == '1'),
+						'label' => lng('antispam.required_spf_dns'),
+						'type' => 'longtext',
+						'value' => (string)(new \Froxlor\Dns\DnsEntry('@', 'TXT', \Froxlor\Dns\Dns::encloseTXTContent(Settings::Get('spf.spf_entry'))))
+					],
+					'dmarc_entry' => [
+						'visible' => (Settings::Get('system.bind_enable') == '0' && Settings::Get('dmarc.use_dmarc') == '1' && $result['isemaildomain'] == '1'),
+						'label' => lng('antispam.required_dmarc_dns'),
+						'type' => 'longtext',
+						'value' => (string)(new \Froxlor\Dns\DnsEntry('_dmarc', 'TXT', \Froxlor\Dns\Dns::encloseTXTContent(Settings::Get('dmarc.dmarc_entry'))))
+					],
+					'dkim_entry' => [
+						'visible' => (Settings::Get('system.bind_enable') == '0' && Settings::Get('antispam.activated') == '1' && $result['dkim'] == '1' && $result['dkim_pubkey'] != ''),
+						'label' => lng('antispam.required_dkim_dns'),
+						'type' => 'longtext',
+						'value' => (string)(new \Froxlor\Dns\DnsEntry('dkim' . $result['dkim_id'] . '._domainkey', 'TXT', \Froxlor\Dns\Dns::encloseTXTContent('v=DKIM1; k=rsa; p='.trim($result['dkim_pubkey']))))
+					],
 				]
 			]
 		]
